@@ -12,7 +12,7 @@ import om_code.omerrors as errors
 import om_code.omgenutils as gu
 
 
-def findODcorrection(wdirpath, ODfname, exp, figs, odmatch):
+def findODcorrection(wdirpath, ODfname, exp, figs, odmatch, cvfn, bd, gp_results):
     """
     Uses a Gaussian process to fit serial dilution data
     to correct for non-linearities in the relationship between OD and cell
@@ -23,7 +23,9 @@ def findODcorrection(wdirpath, ODfname, exp, figs, odmatch):
     print("Fitting dilution data for OD correction for non-linearities")
     if ODfname:
         try:
-            od_df = pd.read_csv(str(wdirpath / ODfname), sep=None, engine="python")
+            od_df = pd.read_csv(
+                str(wdirpath / ODfname), sep=None, engine="python", header=None
+            )
             print("Using", ODfname)
             od_data = od_df.to_numpy()
             od, dilfac = od_data[:, 0], od_data[:, 1]
@@ -171,9 +173,23 @@ def findODcorrection(wdirpath, ODfname, exp, figs, odmatch):
         y = dilfac / dilfacmatch * odmatch
     else:
         y = dilfac
+    # set up Gaussian process
+    bddict = {
+        "sqexplin": {0: (-4, 2), 1: (-3, 1), 2: (-6, 1), 3: (-6, 1)},
+        "nn": {0: (-4, 2), 1: (-3, 1), 2: (-6, 1)},
+        "sqexp": {0: (-4, 2), 1: (-3, 1), 2: (-6, 1)},
+        "matern": {0: (-4, 2), 1: (-3, 1), 2: (-6, 1)},
+    }
+    # find bounds
+    if bd:
+        bds = gu.mergedicts(original=bddict[cvfn], update=bd)
+    else:
+        bds = bddict[cvfn]
+    gc = getattr(gp, cvfn + "GP")(bds, od, y)
     # run Gaussian process
-    gc = gp.sqexplinGP({0: (-4, 2), 1: (-3, 1), 2: (-6, 1), 3: (-6, 1)}, od, y)
     gc.findhyperparameters(noruns=5, exitearly=True, quiet=True)
+    if gp_results:
+        gc.results()
     gc.predict(od)
     if figs:
         plt.figure()
