@@ -18,7 +18,7 @@ import om_code.omstats as omstats
 import om_code.admin as admin
 import om_code.clogger as clogger
 
-version = "0.9.45"
+version = "0.9.47"
 
 plt.rcParams["figure.max_open_warning"] = 0
 sns.set()
@@ -1556,6 +1556,9 @@ class platereader:
         self,
         figs=True,
         odmatch=0.3,
+        cvfn="sqexplin",
+        bd=None,
+        gp_results=False,
         experiments="all",
         experimentincludes=False,
         experimentexcludes=False,
@@ -1580,6 +1583,17 @@ class platereader:
             If non-zero, then the corrected OD is rescaled to equal the
             measured OD at this value. Only large ODs typically need to be
             corrected.
+        cvfn: string
+            The type of kernel function for the Gaussian process either 'sqexp'
+            (squared exponential) or 'sqexplin (squared exponential with a linear trend) or 'matern' (Matern with nu= 5/2) or 'nn'
+            (neural network).
+        bd: dictionary, optional
+            Specifies the limits on the hyperparameters for the Gaussian process.
+            For example, bd= {0: [-1, 4], 2: [2, 6]})
+            sets confines the first hyperparameter to be between 1e-1 and 1e^4
+            and confines the third hyperparmater between 1e2 and 1e6.
+        gp_results: boolean, optional
+            If True, show the results of fitting the Gaussian process
         experiments: string or list of strings
             The experiments to include.
         conditions: string or list of strings
@@ -1627,8 +1641,11 @@ class platereader:
                             self.wdirpath,
                             ODfname,
                             exp,
-                            figs,
-                            odmatch,
+                            figs=figs,
+                            odmatch=odmatch,
+                            cvfn=cvfn,
+                            bd=bd,
+                            gp_results=gp_results,
                         )
                         self.progress["gc"][exp] = gc
                         # copy gc to experiments with the same ODfname
